@@ -32,6 +32,7 @@
 #include <QFile>
 #include <QFileInfo>
 #include <QLoggingCategory>
+#include <private/qtx11extras_p.h>
 
 #include <KSharedConfig>
 #include <kaboutdata.h>
@@ -45,7 +46,7 @@
 
 #include <kdesu/client.h>
 #include <kdesu/defaults.h>
-#include <kdesu/su.h>
+#include <kdesu/suprocess.h>
 
 #include "sudlg.h"
 
@@ -83,7 +84,7 @@ int main(int argc, char *argv[])
         duser = "root";
     }
 
-    KLocalizedString::setApplicationDomain("kdesu5");
+    KLocalizedString::setApplicationDomain(QByteArrayLiteral("kdesu5"));
 
     KAboutData aboutData(QStringLiteral("kdesu"),
                          i18n("KDE su"),
@@ -162,7 +163,7 @@ static int startApp(QCommandLineParser &p)
 {
     // Stop daemon and exit?
     if (p.isSet(QStringLiteral("s"))) {
-        KDEsuClient client;
+        KDESu::Client client;
         if (client.ping() == -1) {
             qCCritical(category) << "Daemon not running -- nothing to stop\n";
             p.showHelp(1);
@@ -267,7 +268,7 @@ static int startApp(QCommandLineParser &p)
     // Check for daemon and start if necessary
     bool just_started = false;
     bool have_daemon = true;
-    KDEsuClient client;
+    KDESu::Client client;
     if (client.ping() == -1) {
         if (client.startServer() == -1) {
             qCWarning(category) << "Could not start daemon, reduced functionality.\n";
@@ -301,7 +302,7 @@ static int startApp(QCommandLineParser &p)
 
     QList<QByteArray> env;
     QByteArray options;
-    env << ("DESKTOP_STARTUP_ID=" + KStartupInfo::startupId());
+    env << ("DESKTOP_STARTUP_ID=" + QX11Info::nextStartupId());
 
     //     TODO: Maybe should port this to XDG_*, somehow?
     //     if (pw->pw_uid)
